/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.doubleclickbidmanager.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Query metadata.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the DoubleClick Bid Manager API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class QueryMetadata extends GenericJson {

  /**
   * Range of report data.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String dataRange;

  /**
   * Format of the generated report.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String format;

  /**
   * The path to the location in Google Cloud Storage where the latest report is stored.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String googleCloudStoragePathForLatestReport;

  /**
   * The path in Google Drive for the latest report.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String googleDrivePathForLatestReport;

  /**
   * The time when the latest report started to run.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long latestReportRunTimeMs;

  /**
   * Number of reports that have been generated for the query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer reportCount;

  /**
   * Whether the latest report is currently running.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean running;

  /**
   * Whether to send an email notification when a report is ready. Default to false.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean sendNotification;

  /**
   * List of email addresses which are sent email notifications when the report is finished.
   * Separate from sendNotification.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> shareEmailAddress;

  /**
   * Query title. It is used to name the reports generated from this query.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * Range of report data.
   * The value returned may be {@code null}.
   */
  public String getDataRange() {
    return dataRange;
  }

  /**
   * Range of report data.
   * The value set may be {@code null}.
   */
  public QueryMetadata setDataRange(String dataRange) {
    this.dataRange = dataRange;
    return this;
  }

  /**
   * Format of the generated report.
   * The value returned may be {@code null}.
   */
  public String getFormat() {
    return format;
  }

  /**
   * Format of the generated report.
   * The value set may be {@code null}.
   */
  public QueryMetadata setFormat(String format) {
    this.format = format;
    return this;
  }

  /**
   * The path to the location in Google Cloud Storage where the latest report is stored.
   * The value returned may be {@code null}.
   */
  public String getGoogleCloudStoragePathForLatestReport() {
    return googleCloudStoragePathForLatestReport;
  }

  /**
   * The path to the location in Google Cloud Storage where the latest report is stored.
   * The value set may be {@code null}.
   */
  public QueryMetadata setGoogleCloudStoragePathForLatestReport(String googleCloudStoragePathForLatestReport) {
    this.googleCloudStoragePathForLatestReport = googleCloudStoragePathForLatestReport;
    return this;
  }

  /**
   * The path in Google Drive for the latest report.
   * The value returned may be {@code null}.
   */
  public String getGoogleDrivePathForLatestReport() {
    return googleDrivePathForLatestReport;
  }

  /**
   * The path in Google Drive for the latest report.
   * The value set may be {@code null}.
   */
  public QueryMetadata setGoogleDrivePathForLatestReport(String googleDrivePathForLatestReport) {
    this.googleDrivePathForLatestReport = googleDrivePathForLatestReport;
    return this;
  }

  /**
   * The time when the latest report started to run.
   * The value returned may be {@code null}.
   */
  public Long getLatestReportRunTimeMs() {
    return latestReportRunTimeMs;
  }

  /**
   * The time when the latest report started to run.
   * The value set may be {@code null}.
   */
  public QueryMetadata setLatestReportRunTimeMs(Long latestReportRunTimeMs) {
    this.latestReportRunTimeMs = latestReportRunTimeMs;
    return this;
  }

  /**
   * Number of reports that have been generated for the query.
   * The value returned may be {@code null}.
   */
  public Integer getReportCount() {
    return reportCount;
  }

  /**
   * Number of reports that have been generated for the query.
   * The value set may be {@code null}.
   */
  public QueryMetadata setReportCount(Integer reportCount) {
    this.reportCount = reportCount;
    return this;
  }

  /**
   * Whether the latest report is currently running.
   * The value returned may be {@code null}.
   */
  public Boolean getRunning() {
    return running;
  }

  /**
   * Whether the latest report is currently running.
   * The value set may be {@code null}.
   */
  public QueryMetadata setRunning(Boolean running) {
    this.running = running;
    return this;
  }

  /**
   * Whether to send an email notification when a report is ready. Default to false.
   * The value returned may be {@code null}.
   */
  public Boolean getSendNotification() {
    return sendNotification;
  }

  /**
   * Whether to send an email notification when a report is ready. Default to false.
   * The value set may be {@code null}.
   */
  public QueryMetadata setSendNotification(Boolean sendNotification) {
    this.sendNotification = sendNotification;
    return this;
  }

  /**
   * List of email addresses which are sent email notifications when the report is finished.
   * Separate from sendNotification.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getShareEmailAddress() {
    return shareEmailAddress;
  }

  /**
   * List of email addresses which are sent email notifications when the report is finished.
   * Separate from sendNotification.
   * The value set may be {@code null}.
   */
  public QueryMetadata setShareEmailAddress(java.util.List<String> shareEmailAddress) {
    this.shareEmailAddress = shareEmailAddress;
    return this;
  }

  /**
   * Query title. It is used to name the reports generated from this query.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * Query title. It is used to name the reports generated from this query.
   * The value set may be {@code null}.
   */
  public QueryMetadata setTitle(String title) {
    this.title = title;
    return this;
  }

}
